@@ -1,8 +1,8 @@
 import { fireEvent, render, screen } from '@testing-library/react';
 
 import { getDefaultTimeRange } from '@grafana/data';
-import { ElasticsearchDataQuery } from 'app/plugins/datasource/elasticsearch/dataquery.gen';
 
+import { ElasticsearchDataQuery } from '../../../../dataquery.gen';
 import { ElasticDatasource } from '../../../../datasource';
 import { ElasticsearchProvider } from '../../ElasticsearchQueryContext';
 
